# To-Dos
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/to-dos#overview)
  * [Types of To-Dos](https://help.sap.com/docs/leanix/ea/to-dos#types-of-to-dos)
  * [Creating To-Dos](https://help.sap.com/docs/leanix/ea/to-dos#creating-to-dos)
  * [Accessing To-Dos](https://help.sap.com/docs/leanix/ea/to-dos#accessing-to-dos)
  * [Modifying To-Do Items](https://help.sap.com/docs/leanix/ea/to-dos#modifying-to-do-items)
  * [Claiming and Assigning To-Dos](https://help.sap.com/docs/leanix/ea/to-dos#claiming-and-assigning-to-dos)
  * [Completing To-Do Tasks](https://help.sap.com/docs/leanix/ea/to-dos#completing-to-do-tasks)
  * [Restricting To-Do Completion to Assignees](https://help.sap.com/docs/leanix/ea/to-dos#restricting-to-do-completion-to-assignees)
  * [Notifications](https://help.sap.com/docs/leanix/ea/to-dos#notifications)


To-dos facilitate task delegation, collaboration, and governance and can be used to ensure data integrity and quality through transparent task management.
